View source: R/column_orderings.R
| column_orderings_matrix | R Documentation |
df.
A TRUE at (i,j) in the returned matrix values in column are >= to corresponding
values in column j (ignoring rows where either column has an NA).Adjacency matrix recording orderings between all pairs of columns in data frame df.
A TRUE at (i,j) in the returned matrix values in column are >= to corresponding
values in column j (ignoring rows where either column has an NA).
column_orderings_matrix(df)
df |
A data frame. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.